==> eiffelstudio-16.05.tar: F_code/C2/kl58.c <==
/*
 * Code for class KL_SYSTEM_CLOCK
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "kl58.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {KL_SYSTEM_CLOCK}.make */
void F79_990 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {KL_SYSTEM_CLOCK}.year */
EIF_INTEGER_32 F79_991 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_);
}


/* {KL_SYSTEM_CLOCK}.month */
EIF_INTEGER_32 F79_992 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_);
}


/* {KL_SYSTEM_CLOCK}.day */
EIF_INTEGER_32 F79_993 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_);
}


/* {KL_SYSTEM_CLOCK}.hour */
EIF_INTEGER_32 F79_994 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_);
}


/* {KL_SYSTEM_CLOCK}.minute */
EIF_INTEGER_32 F79_995 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
}


/* {KL_SYSTEM_CLOCK}.second */
EIF_INTEGER_32 F79_996 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_);
}


/* {KL_SYSTEM_CLOCK}.millisecond */
EIF_INTEGER_32 F79_997 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_);
}


/* {KL_SYSTEM_CLOCK}.set_local_time */
void F79_998 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		tr1 = RTLNS(eif_new_type(10, 0x00).id, 10, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F11_144(RTCW(tr1));
		loc1 = (EIF_REFERENCE) tr1;
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc1;
	} else {
		F11_147(RTCW(loc1));
	}
	ti4_1 = F11_148(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_149(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_150(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_151(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_152(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_153(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_0_);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {KL_SYSTEM_CLOCK}.set_utc_time */
void F79_999 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		tr1 = RTLNS(eif_new_type(10, 0x00).id, 10, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F11_145(RTCW(tr1));
		loc1 = (EIF_REFERENCE) tr1;
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
	} else {
		F11_147(RTCW(loc1));
	}
	ti4_1 = F11_148(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_149(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_150(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_151(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_152(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_153(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_0_);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {KL_SYSTEM_CLOCK}.utc_clock */
EIF_REFERENCE F79_1000 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {KL_SYSTEM_CLOCK}.local_clock */
EIF_REFERENCE F79_1001 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit58 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C2/kl58.c <==
/*
 * Code for class KL_SYSTEM_CLOCK
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "kl58.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {KL_SYSTEM_CLOCK}.make */
void F79_1107 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {KL_SYSTEM_CLOCK}.year */
EIF_INTEGER_32 F79_1108 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_);
}


/* {KL_SYSTEM_CLOCK}.month */
EIF_INTEGER_32 F79_1109 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_);
}


/* {KL_SYSTEM_CLOCK}.day */
EIF_INTEGER_32 F79_1110 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_);
}


/* {KL_SYSTEM_CLOCK}.hour */
EIF_INTEGER_32 F79_1111 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_);
}


/* {KL_SYSTEM_CLOCK}.minute */
EIF_INTEGER_32 F79_1112 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
}


/* {KL_SYSTEM_CLOCK}.second */
EIF_INTEGER_32 F79_1113 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_);
}


/* {KL_SYSTEM_CLOCK}.millisecond */
EIF_INTEGER_32 F79_1114 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_);
}


/* {KL_SYSTEM_CLOCK}.set_local_time */
void F79_1115 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		loc1 = RTLNS(eif_new_type(8, 0x01).id, 8, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F9_68(RTCW(loc1));
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc1;
	} else {
		F9_71(RTCW(loc1));
	}
	ti4_1 = F9_72(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F9_73(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F9_74(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F9_75(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F9_76(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F9_77(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F9_78(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {KL_SYSTEM_CLOCK}.set_utc_time */
void F79_1116 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		loc1 = RTLNS(eif_new_type(8, 0x01).id, 8, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F9_69(RTCW(loc1));
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
	} else {
		F9_71(RTCW(loc1));
	}
	ti4_1 = F9_72(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F9_73(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F9_74(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F9_75(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F9_76(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F9_77(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F9_78(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

void EIF_Minit58 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
